magneticalc.Debug.Debug

# ``magneticalc`.`Debug`.`Debug``

class documentation

`class Debug:`

Constructor: `Debug(obj, text, color, force, ...)`

View In Hierarchy

Debug class.

Method | `__init__` | Displays a colorful debug message and the current call hierarchy.
Class Variable | `Blacklist` | Undocumented
Class Variable | `EnableBlacklist` | Undocumented
Class Variable | `EnableInit` | Undocumented
Class Variable | `EnableRefresh` | Undocumented

def __init__(self, obj: `object`, text: `str`, color: `Style | None` = None, force: `bool` = False, success: `bool` = False, warning: `bool` = False, error: `bool` = False, init: `bool` = False, refresh: `bool` = False):

Displays a colorful debug message and the current call hierarchy.

Parameters
obj: `object` | Class instance
text: `str` | Debug message
color: `Style | None` | Color (may be None)
force: `bool` | Enable to override whitelist
success: `bool` | Enable to set color=SuccessColor
warning: `bool` | Enable to set color=WarningColor and force=True
error: `bool` | Enable to set color=ErrorColor and force=True
init: `bool` | Enable to mark as init message (filtering through EnableInit)
refresh: `bool` | Enable to mark as refresh message (filtering through EnableRefresh)

Blacklist: `list[str]` =

Undocumented

EnableBlacklist: `bool` =

Undocumented

EnableInit: `bool` =

Undocumented

EnableRefresh: `bool` =

Undocumented